#define BUILD_NUMBER \
	"build-20219665"
#define BUILD_NUMBER_NUMERIC \
	20219665
#define BUILD_NUMBER_NUMERIC_STRING \
	"20219665"
#define PRODUCT_BUILD_NUMBER \
	"product-build-37487"
#define PRODUCT_BUILD_NUMBER_NUMERIC \
	37487
#define PRODUCT_BUILD_NUMBER_NUMERIC_STRING \
	"37487"
